[**中文版说明**](./README.md) |


albert_chinese_pytorch目录下

加入flask 标记数据

宠物内容识别模型下载
https://www.kaggle.com/terrychanorg/albert-chinese-pytorch-pet
下载模型放入albert_chinese_pytorch/prev_trained_model/terry_output